@@ -13,8 +13,11 @@ def NumOCR(path, label=None, debug=False, show=False):
     ImageFile.close()
 
     # Calling for trained model
-    os.chdir("./MNIST2")
-    ThetaArray = np.load("theta.npy")
+    try:
+        ThetaArray = np.load("theta.npy")
+    except:
+        os.chdir("./MNIST2")
+        ThetaArray = np.load("theta.npy")
 
     # Comparison
     ThetaArray = np.fabs(ThetaArray - ContentArray)
@@ -31,3 +34,6 @@ def NumOCR(path, label=None, debug=False, show=False):
 
     if label:
         return True if Prediction == label else False
+
+if __name__ == "__main__":
+    NumOCR("tmpl6deljrh.PNG", label=None, debug=False, show=False)
\ No newline at end of file
